@@ -26,11 +26,17 @@ typedef int _vtype;
 
 class Value;
 
+using std::string;
+
 //=============================================================================
 
 class Notify {
+
 public:
-	virtual void trigger(void*) = 0;
+   Notify() {}
+   ~Notify() {}
+
+   virtual void trigger(void*) = 0;
 };
 
 class Reference {
@@ -245,26 +251,39 @@ public:
 //=============================================================================
 
 class CGrib  : public InPool {
-	fieldset  *fs;
-	hypercube *cube;
-	virtual void ToFieldset(fieldset* &x) { x = fs; };
-	virtual void ToRequest(request* &);
-	virtual void ToGrib(CGrib*       &x) { x = this;};
-	virtual void Print(void);
-	virtual int  Write(FILE*);
-	virtual Content *Clone(void);
-	virtual void SetSubValue(Value&,int,Value*);
-	virtual void Dump2();
-    void DestroyContent();
+
+   fieldset  *fs;
+   hypercube *cube;
+   string    path_;  // It stores an absolute path. This is important
+                     // specially if request parameter PATH contains
+                     // a relative path. 
+   
+   virtual void ToFieldset(fieldset* &x)
+      { x = fs; }
+
+   virtual void ToRequest(request* &);
+   virtual void ToGrib(CGrib* &x)
+      { x = this; }
+
+   virtual void Print(void);
+   virtual int  Write(FILE*);
+   virtual Content *Clone(void);
+   virtual void SetSubValue(Value&,int,Value*);
+   virtual void Dump2();
+   void DestroyContent();
 
 public:
-	CGrib(const char *);
-	CGrib(request  *);
-	CGrib(fieldset  *);
-	fieldset *GetFieldset(void)       { return fs; };
-	void SetFileTempFlag(boolean);
-	~CGrib();
-	hypercube* get_cube();
+   CGrib(const char*);
+   CGrib(request*);
+   CGrib(fieldset*);
+
+   ~CGrib();
+
+   fieldset *GetFieldset(void)
+      { return fs; };
+      
+   void SetFileTempFlag(boolean);
+   hypercube* get_cube();
 };
 
 
