@@ -21,6 +21,11 @@
 #include "script.h"
 #include "cbufr.h"
 
+
+#define QUOTE_PP(P) #P
+#define QUOTE_PPP(P) QUOTE_PP(P)
+
+
 //=============================================================================
 
 class NilFunction : public Function {
@@ -790,8 +795,15 @@ Value MetviewVersionFunction::Execute(int arity,Value *arg)
 	}
 
 
+	// extra code to take into account the possibility of
+	// using either GRIB_API or ecCodes for GRIB handling
+	std::string grib_package=QUOTE_PPP(GRIB_HANDLING_PACKAGE);
+	for(unsigned int i = 0; i < grib_package.length(); ++i)
+		grib_package[i] = tolower(grib_package[i]);
+	grib_package += "_version";
+
 	grib_api_version = grib_get_api_version();
-	set_value(r, "grib_api_version", "%d", grib_api_version);
+	set_value(r, grib_package.c_str(), "%d", grib_api_version);
 
 	mars_version = marsversion();
 	set_value(r, "mars_version", "%d", mars_version);
