@@ -61,6 +61,15 @@ enum eVectorSortType
 };
 
 
+
+enum eVectorIndexType
+{
+    VINDEX_NUMBERS,
+    VINDEX_VECTOR
+};
+
+
+
 /*******************************************************************************
  *
  * Function      : CVector::CVector(int)
@@ -730,7 +739,9 @@ Value Vector2Function::Execute(int ,Value *arg)
  *                 last element to be extracted - if supplied, then a vector
  *                 is returned. A third argument is an optional step size.
  *                 A fourth argument tells us how many elements to extract
- *                 at each step.
+ *                 at each step. Alternatively, a vector can be supplied
+ *                 instead of all these numbers - e.g. a vector index with
+ *                 6 elements will return a resulting vector with 6 elements.
  *
  ******************************************************************************/
 
@@ -739,6 +750,8 @@ public:
 	VectorGetElemFunction(char *n) : Function(n,2,tvector,tnumber) {};
 	virtual Value Execute(int arity,Value *arg);
 	virtual int ValidArguments(int arity,Value *arg);
+private:
+	eVectorIndexType indexType_;
 };
 
 int VectorGetElemFunction::ValidArguments(int arity,Value *arg)
@@ -746,9 +759,26 @@ int VectorGetElemFunction::ValidArguments(int arity,Value *arg)
 	if(arity<2 || arity > 5) return false;
 	if(arg[0].GetType() != tvector) return false;
 
-	for(int i=1;i<arity;i++) // all arguments after the first one must be numbers
-		if(arg[i].GetType() != tnumber)
+
+	// indexing can either be a set of numbers or a single vector
+	if (arg[1].GetType() == tvector)  // vector
+	{
+		if (arity > 2)
 			return false;
+		else
+		{
+			indexType_ = VINDEX_VECTOR;
+			return true;
+		}
+	}
+	else  // number(s)
+	{
+		indexType_ = VINDEX_NUMBERS;
+
+		for(int i=1;i<arity;i++) // all arguments after the first one must be numbers
+			if(arg[i].GetType() != tnumber)
+				return false;
+	}
 
 	return true;
 }
@@ -756,41 +786,66 @@ int VectorGetElemFunction::ValidArguments(int arity,Value *arg)
 
 Value VectorGetElemFunction::Execute(int arity,Value *arg)
 {
-    CVector *v;
-    int  first;
-    int  last   = 0; // index of first element
-    int  step   = 0; // step
-    int  length = 1; // how many we extract at each step
+	if (indexType_ == VINDEX_NUMBERS)
+	{
+		CVector *v;
+		int  first;
+		int  last   = 0; // index of first element
+		int  step   = 0; // step
+		int  length = 1; // how many we extract at each step
 
-    arg[0].GetValue(v);
-    arg[1].GetValue(first);
-    if (arity>2) arg[2].GetValue(last);
-    if (arity>3) arg[3].GetValue(step);
-    if (arity>4) arg[4].GetValue(length);
+		arg[0].GetValue(v);
+		arg[1].GetValue(first);
+		if (arity>2) arg[2].GetValue(last);
+		if (arity>3) arg[3].GetValue(step);
+		if (arity>4) arg[4].GetValue(length);
 
-    if (last <  first) last = first;
-    if (step <= 0) step = 1;
+		if (last <  first) last = first;
+		if (step <= 0) step = 1;
 
-    if (last+length-step >  v->Count())
-       return Error("last element out of range. last is %d, vector size is %d",
-            last+length-step,v->Count());
+		if (last+length-step >  v->Count())
+		   return Error("last element out of range. last is %d, vector size is %d",
+				last+length-step,v->Count());
 
-    if (first <1 || first>v->Count())
-        return Error("first out of range. first is %d, vector size is %d",
-            first,v->Count());
+		if (first <1 || first>v->Count())
+			return Error("first out of range. first is %d, vector size is %d",
+				first,v->Count());
 
-    if ((last == first) && (length == 1))
-        return (*v)[first-1];
+		if ((last == first) && (length == 1))
+			return (*v)[first-1];
 
 
-    int c = ((last-first)/step+1) * length;
-    CVector *vnew = new CVector(c);
-    int i,j;
+		int c = ((last-first)/step+1) * length;
+		CVector *vnew = new CVector(c);
+		int i,j;
 
-    for (i = 0, j = first-1 ; i < c ; i+=length, j += step)
-        vnew->CopyValues(i, *v, j, length);
+		for (i = 0, j = first-1 ; i < c ; i+=length, j += step)
+			vnew->CopyValues(i, *v, j, length);
 
-    return Value(vnew);
+		return Value(vnew);
+	}
+
+	else  // vector indexing (i.e. the index is itself a vector of indexes)
+	{
+		CVector *v;
+		CVector *vi;
+		arg[0].GetValue(v);
+		arg[1].GetValue(vi);
+
+		// the result vector
+		CVector *vnew = new CVector(vi->Count());
+		for (int i = 0; i < vi->Count(); i++)
+		{
+			int index = (*vi)[i];
+			if (index < 1 || index > v->Count())
+				return Error("index %d(%d) is out of range. Vector size is %d", i+1, index, v->Count());
+
+			(*vnew)[i] = (*v)[index-1];  // -1 to convert from 1-index (Macro) to 0-index (C)
+		}
+
+		return Value(vnew);
+
+	}
 }
 
 
@@ -1380,6 +1435,87 @@ Value VectorSort::Execute(int arity,Value *arg)
     return Value(v2);
 }
 
+//=============================================================================
+
+class VectorFindFunction : public Function {
+public:
+	VectorFindFunction(const char *n) : Function(n,2,tany,tvector)
+	{ info="Find where a number occurs in a vector";};
+	virtual Value Execute(int arity,Value *arg);
+	virtual int ValidArguments(int arity,Value *arg);
+};
+
+
+int VectorFindFunction::ValidArguments(int arity,Value *arg)
+{
+    if(arity != 2 && arity != 3)    return false;
+	if(arg[0].GetType() != tvector) return false;                  // first arg must be a vector
+	if(arg[1].GetType() != tnumber) return false;                  // second arg must be a number
+	if((arity == 3) && arg[2].GetType() != tstring) return false;  // third (optional) arg must be a string
+	return true;
+}
+
+
+Value VectorFindFunction::Execute(int arity,Value *arg)
+{
+    CVector *v;
+    double d;
+    bool findAll = false;
+
+    if (arity == 3)
+    {
+        const char *s;
+        arg[2].GetValue(s);
+        if (s && !strcmp(s, "all"))
+            findAll = true;
+        else
+            marslog(LOG_WARN, "find(vector, number, string) only accepts 'all' as its last argument. Supplied: '%s'", s);
+    }
+
+    arg[0].GetValue(v);
+    arg[1].GetValue(d);
+
+
+    std::vector<int> results;  // only need a vector if we're looking for more than 1 result
+
+    for(int i=0;i<v->Count();i++)
+    {
+        if((*v)[i] == d)                   // does it match?
+        {
+            if (findAll)
+            {
+                results.push_back(i+1);    // we want 'all', so add to our list
+            }
+            else
+            {
+                return Value(i+1);         // we want just the first, to return it
+            }
+        }
+    }
+
+
+    if (findAll)
+    {
+        if (results.size() > 0)
+        {
+            CVector *outvec = new CVector(results.size());
+
+            for(unsigned int i=0; i < results.size(); i++)
+            {
+                (*outvec)[i] = results[i];
+            }
+            return Value(outvec);
+        }
+        else
+        {
+            return Value();  // looked for all the values, but did not find any - return nil
+        }
+    }
+    else  // looked for the first value, but did not find it - return nil
+    {
+        return Value();
+    }
+}
 
 
 //===========================================================================
@@ -1511,6 +1647,7 @@ static void install(Context *c)
 	c->AddFunction(new VectorBitmap("bitmap"));
 	c->AddFunction(new VectorNoBitmap("nobitmap"));
 	c->AddFunction(new VectorFilter("filter"));
+	c->AddFunction(new VectorFindFunction("find"));
 	c->AddFunction(new VectorSort("sort",         VSORT_VALUES));
 	c->AddFunction(new VectorSort("sort_indices", VSORT_INDICES));
 
