@@ -13,6 +13,8 @@
 #include "macro.h"
 #include "script.h"
 #include "value.h"
+
+#include "MvPath.hpp"
 #include "MvRequest.h"
 #include "MvApplication.h"
 
@@ -22,6 +24,9 @@ static Cache LangCache;
 static Cache TestCache;
 static Cache ObjsCache;
 
+static const char* M_UPLOT = "uPlotManager";
+
+
 static const char *find_service(const char *verb,const char *mode)
 {
 	char *state = strcache("state");
@@ -608,8 +613,10 @@ Value SimpleRequestFunction::Execute(int arity ,Value *arg)
 		set_subrequest(r,"_DEVICE_DRIVER",s);  //-- directrly for new PlotMod
 	   }
 #endif
-	   set_value(r,"_MACRO","%s",Script::MacroPath());
-	   set_value(r,"_PATH","%s",Script::MacroMainPath());
+
+      set_value(r,"_MACRO","%s",Script::MacroPath());
+      string fullPath = MakeAbsolutePath((const char*)get_value(r,"PATH",0),dirname(Script::MacroMainPath()));
+      set_value(r,"_PATH",fullPath.c_str());
 	}
 
 	v = service ? Value(service,r,attachedContent) : Value(r);
@@ -1004,7 +1011,8 @@ Value ComplexRequestFunction::Execute(int arity ,Value *arg)
     }
 
     set_value(p,"_MACRO","%s",Script::MacroPath());
-    set_value(p,"_PATH","%s",Script::MacroMainPath());
+    string fullPath = MakeAbsolutePath((const char*)get_value(p,"PATH",0),dirname(Script::MacroMainPath()));
+    set_value(p,"_PATH",fullPath.c_str());
 
     Value v(Service(),p);
     free_all_requests(p);
@@ -1101,9 +1109,11 @@ Value PlotFunction::ExecuteComplexRequestFunction(int arity ,Value *arg)
 		}
 	}
 
-	set_value(p,"_MACRO","%s",Script::MacroPath());
-	set_value(p,"_PATH","%s",Script::MacroMainPath());
-	set_value(p,"_NAME",Context::UniqueName());
+   // Add hidden parameters
+   set_value(p,"_MACRO","%s",Script::MacroPath());
+   set_value(p,"_NAME",Context::UniqueName());
+   string fullPath = MakeAbsolutePath((const char*)get_value(p,"PATH",0),dirname(Script::MacroMainPath()));
+   set_value(p,"_PATH",fullPath.c_str());
 
 	// Define output requests according to the following rules/priorities:
 	// 1. Drivers defined in the "plot" command have top priority (overwrite "setoutput")
