@@ -1028,6 +1028,10 @@ void MacroEdit::showFindDialog(bool showReplaceOptions)
                 this, SLOT(replaceStringInFile(const QString &,const QString &,QTextDocument::FindFlags)));
 
         connect(findDialog_, SIGNAL(rejected()), this, SLOT(findClosed()));
+
+        connect(textEditor, SIGNAL(selectionChanged()), this, SLOT(onSelectionChanged()));
+
+        connect(this, SIGNAL(selectionChanged(bool)), findDialog_, SLOT(onSelectionChanged(bool)));
     }
 
 
@@ -1171,7 +1175,15 @@ void MacroEdit::findString(const QString &s,QTextDocument::FindFlags flags, bool
 
 void MacroEdit::replaceString(const QString &s,const QString &r,QTextDocument::FindFlags flags)
 {
-    findString(s, flags, true, r);
+    // perform the 'replace'
+    textEditor->insertPlainText (r);
+
+    // highlight the replaced text - the current text cursor will be
+    // at the end of the replaced text, so we move it back to the start
+    // (anchored so that the text is selected)
+    QTextCursor cursor = textEditor->textCursor();   // get the document's cursor
+    cursor.movePosition(QTextCursor::Left, QTextCursor::KeepAnchor, r.length());
+    textEditor->setTextCursor(cursor);               // send the cursor back to the document
 }
 
 
@@ -1584,6 +1596,23 @@ void MacroEdit::onRunOptionsChanged (MacroRunOptions options)
 
 
 
+// ---------------------------------------------------------------------------
+// MacroEdit::onSelectionChanged
+// triggered when the user changes the text selection
+// ---------------------------------------------------------------------------
+
+void MacroEdit::onSelectionChanged()
+{
+    // if the find/replace dialogue is open, it needs to know about the change
+
+    if (findDialog_)
+    {
+        bool isSelection = textEditor->textCursor().hasSelection();
+        emit selectionChanged(isSelection);
+    }
+}
+
+
 
 // ---------------------------------------------------------------------------
 // MacroEdit::onReadOnlyStatusChanged
