@@ -7,7 +7,11 @@
 
  ***************************** LICENSE END *************************************/
 
-#include <QtGui>
+#ifdef METVIEW_QT5
+ #include <QtWidgets>
+#else
+ #include <QtGui>
+#endif
 
 #include "VerbFunctionHelp.h"
 
