@@ -29,6 +29,9 @@ const int   cLatBandCount = (int)( 180.0 / cLatBandSize ) + 1;
 const int   G2G_RECIPROCAL       = 0;
 const int   G2G_EXPONENTIAL_MEAN = 1;
 const int   G2G_EXPONENTIAL_SUM  = 2;
+const int   G2G_NEAREST_MEAN     = 3;
+const int   G2G_NEAREST_SUM      = 4;
+const int   G2G_NEAREST_COUNT    = 5;
 
 double makeDateNumber( long date, long time );
 
@@ -65,6 +68,9 @@ public:
     bool estimate();
     bool estimateToUserGrid();
     bool estimateToTemplateGrid();
+    bool estimateNearestToTemplateGrid();
+    void setupUserMatrix(bool zero);
+    bool convertUserToTemplateGrid();
     double value(float lat, float lon);
     void sortPoints();
     string &errorMessage() {return errorMessage_;};
@@ -170,8 +176,14 @@ ToMatrix::ToMatrix(MvRequest& def)
         Weight_ = G2G_RECIPROCAL;
     else if ( st == "EXPONENTIAL_MEAN" )
         Weight_ = G2G_EXPONENTIAL_MEAN;
-    else
+    else if ( st == "EXPONENTIAL_SUM" )
         Weight_ = G2G_EXPONENTIAL_SUM;
+    else if ( st == "NEAREST_GRIDPOINT_MEAN" )
+        Weight_ = G2G_NEAREST_MEAN;
+    else if ( st == "NEAREST_GRIDPOINT_SUM" )
+        Weight_ = G2G_NEAREST_SUM;
+    else
+        Weight_ = G2G_NEAREST_COUNT;
 
 
     MvRequest data;
@@ -294,17 +306,30 @@ void ToMatrix::sortPoints()
 
 bool ToMatrix::estimate()
 {
-    if (gribDefMode == User)
-        return estimateToUserGrid();
+    if (Weight_ == G2G_NEAREST_MEAN || Weight_ == G2G_NEAREST_SUM || Weight_ == G2G_NEAREST_COUNT)
+    {
+        //  if User, convert to Template, because we need that on order to use these modes
+
+        if (gribDefMode == User)
+            if (!convertUserToTemplateGrid())
+                return false;
+
+        return estimateNearestToTemplateGrid();
+    }
     else
-        return estimateToTemplateGrid();
+    {
+        if (gribDefMode == User)
+            return estimateToUserGrid();
+        else
+            return estimateToTemplateGrid();
+    }
 }
+
+
 //_____________________________________________________________________
 
-bool ToMatrix::estimateToUserGrid()
+void ToMatrix::setupUserMatrix(bool zero)
 {
-  int   i, j;
-  float lat,lon;
   double epsilon=0.001;
   
   double oriEast=East;
@@ -340,6 +365,19 @@ bool ToMatrix::estimateToUserGrid()
 #endif
 
   Matrix = new double[NbLon*NbLat];
+  
+  if (zero)
+    memset(Matrix, 0, NbLon*NbLat*sizeof(double));  // set all values to zero
+}
+
+//_____________________________________________________________________
+
+bool ToMatrix::estimateToUserGrid()
+{
+  int   i, j;
+  float lat,lon;
+
+  setupUserMatrix(false);
 
   lat = North;
   for (j = 0; j < NbLat; j++) 
@@ -392,6 +430,106 @@ bool ToMatrix::estimateToTemplateGrid()
 
     return true;
 }
+
+//_____________________________________________________________________
+
+bool ToMatrix::estimateNearestToTemplateGrid()
+{
+    unsigned int *numClosest;
+    templateField->setShape(expand_mem);
+    MvGridBase *grid = templateField->mvGrid();  // be careful with this pointer because MvField is in charge!
+
+    if (!grid->hasLocationInfo())       //-- check that it is ok
+    {
+        errorMessage_ = "Template GRIB field grid locations cannot be read by Metview.";
+        return false;
+    }
+
+    numValsInTemplateGrib = templateField->countValues();
+
+
+    Matrix = new double[numValsInTemplateGrib];               // create the matrix to hold the result
+    memset(Matrix, 0, numValsInTemplateGrib*sizeof(double));  // set all values to zero
+
+
+    if (Weight_ == G2G_NEAREST_MEAN)
+    {
+        // create matrix (zeroed) to store how many gpts are assinged to each grid point
+        numClosest = new unsigned int[numValsInTemplateGrib];  
+        memset(numClosest, 0, numValsInTemplateGrib*sizeof(unsigned int));
+    }
+
+
+    // for each geopoint, find the nearest gridpoint and add the geopoint's value to that gridpoint
+    long ngeo = GPoints.count();
+    for (long i = 0; i < ngeo; i++)
+    {
+        MvGeoP1 gp = GPoints[i];
+        MvGridPoint gridpt = grid->nearestGridpoint(gp.lat_y(), gp.lon_x());
+        if (Weight_ == G2G_NEAREST_COUNT)
+            Matrix[gridpt.index_]++;              // G2G_NEAREST_COUNT
+        else
+            Matrix[gridpt.index_] += gp.value();  // G2G_NEAREST_MEAN or G2G_NEAREST_SUM
+
+
+        if (Weight_ == G2G_NEAREST_MEAN)
+            numClosest[gridpt.index_]++;
+    }
+
+
+    // mean? then divide by the number of points
+    if (Weight_ == G2G_NEAREST_MEAN)
+    {
+        for (long j=0; j<numValsInTemplateGrib; j++)
+            if (numClosest[j] != 0)
+                Matrix[j] /= numClosest[j];
+
+        delete[] numClosest;
+    }
+
+
+    return true;
+}
+
+//_____________________________________________________________________
+
+bool ToMatrix::convertUserToTemplateGrid()
+{
+    // the user has supplied grid parameters, but we want to convert this into
+    // an actual GRIB file so that we can use it as a template
+
+    setupUserMatrix(true);
+
+    string llmatrixpath;
+    if (save(llmatrixpath))
+    {
+        marslog( LOG_INFO, "geo_to_grib: can not write matrix into file %s", llmatrixpath.c_str());
+        return false;
+    }
+
+    string tmpGribFile = marstmp();
+
+    if( LLMatrixToGRIB( llmatrixpath.c_str(), tmpGribFile.c_str() ) )
+    {
+        marslog( LOG_INFO, "geo_to_grib: conversion from geo/LLMatrix to GRIB failed");
+        return false;
+    }
+
+    unlink(llmatrixpath.c_str());  // remove the temporary LLMATRIX file
+
+
+
+
+    MvFieldSet fieldset(tmpGribFile.c_str()) ;  // load it up
+    templateField = new MvField(fieldset[0].libmars_field());
+
+    gribDefMode = Grib;
+
+    return true;
+}
+
+
+
 //_____________________________________________________________________
 
 int ToMatrix::save(string &path)  // returns path to caller
@@ -490,7 +628,7 @@ void GeoToGRIB::serve( MvRequest& in, MvRequest& out )
 
       if( LLMatrixToGRIB( path.c_str(), tmpGribFile.c_str() ) )
       {
-          setError( 1, "geo_to_grib: convertion from geo/LLMatrix to GRIB failed" );
+          setError( 1, "geo_to_grib: conversion from geo/LLMatrix to GRIB failed" );
           return;
       }
 
