@@ -1545,7 +1545,11 @@ void MvQWmsUiClient::slotReplyPreview(QNetworkReply* reply)
 
 void MvQWmsUiClient::slotReplyLegend(QNetworkReply* reply)
 {
-	QNetworkRequest r=reply->request();
+    Q_ASSERT(reply == legendReply_);
+
+    qDebug() << "MvQWmsUiClient::slotReplyLegend -->";
+
+    QNetworkRequest r=reply->request();
 	QUrl url=r.url();
 
 	//qDebug() << url.toString();
@@ -1702,7 +1706,9 @@ bool MvQWmsUiClient::legendDownloadActive()
 
 void MvQWmsUiClient::slotAbortDownloadProcess()
 {
-	if(getCapReply_ && getCapReply_->isRunning())
+    qDebug() << "MvQWmsUiClient::slotAbortDownloadProcess -->";
+
+    if(getCapReply_ && getCapReply_->isRunning())
 	{
 		LogItem *log=new LogItem;
 		LogHandler::instance()->add(log);
