@@ -23,53 +23,49 @@ BufrThermo::BufrThermo() :
                    pCount_(0),
                    nlev_(0),
                    nTIME_STR_(13)
-{
-   //type_ = "MXSECTION";
-   //view_ = "MXSECTIONVIEW";
-}
+{ }
 
 BufrThermo::BufrThermo(const char* kw) :
                    Thermo(kw)
-{
-   //type_ = kw;
-   //view_ = "MXSECTIONVIEW";
-}
+{ }
 
 void
 BufrThermo::allocateDataMemory()
 {
-      pCount_ = 0;
-      T_.clear(); TD_.clear();
-      U_.clear(); V_.clear();
-      P_.clear();
+   pCount_ = 0;
+   T_.clear(); TD_.clear();
+   U_.clear(); V_.clear();
+   P_.clear();
 
-      // Allocate memory
-      if ( nlev_ > 0 )
-      {
-         T_.resize(nlev_);
-         TD_.resize(nlev_);
-         U_.resize(nlev_);
-         V_.resize(nlev_);
-         P_.resize(nlev_);
-      }
+   // Allocate memory
+   if ( nlev_ > 0 )
+   {
+      T_.resize(nlev_);
+      TD_.resize(nlev_);
+      U_.resize(nlev_);
+      V_.resize(nlev_);
+      P_.resize(nlev_);
+   }
 }
 
 void
 BufrThermo::initialiseDataMemory()
 {
-      pCount_ = 0;
-      for ( int i = 0; i < nlev_; i++ )
-      {
-         T_[i]  = MissingValue;
-         TD_[i] = MissingValue;
-         U_[i]  = MissingValue;
-         V_[i]  = MissingValue;
-         P_[i]  = MissingValue;
-      }
+   pCount_ = 0;
+   for ( int i = 0; i < nlev_; i++ )
+   {
+      T_[i]  = MissingValue;
+      TD_[i] = MissingValue;
+      U_[i]  = MissingValue;
+      V_[i]  = MissingValue;
+      P_[i]  = MissingValue;
+   }
 }
 
 bool BufrThermo::getAppParameters( MvRequest& in )
 {
+   // It is expected that the input request is expanded
+
    // Get station input parameter
    station_ = in.getSubrequest("STATION");
    if ( !station_ )
@@ -82,9 +78,10 @@ bool BufrThermo::getAppParameters( MvRequest& in )
 }
 
 // The data structure contains vectors for Temp, Td, Wind and Pressure.
-// There is only one Pressure vector related to the other 3 data. This means
-// that these 3 data may contain different number of Missing values, which will
-// be allocated in those positions when there is no Pressure level defined.
+// There is only one Pressure vector related to the other 3 data. This
+// means that these 3 data may contain different number of Missing 
+// values, which will be allocated in those positions when there is no
+// Pressure level defined.
 bool BufrThermo::processData()
 {
    // If it is not a BUFR data then it has been already processed
@@ -335,22 +332,12 @@ bool BufrThermo::ncInit(MvNetCDF &netcdf, MvObs& obs)
 
 bool BufrThermo::createOutputRequest(MvRequest& out)
 {
-   //MUDE ESTE TESTE PARA UMA FUNCAO. SUBSTITUA TAMBEM NA SUBROUTINA ACIMA
-   // If it is not a GRIB data then it has been already processed
-//   if ( strcmp(pars_.dataReq_.getVerb(),"GRIB") != 0 )
-//      return createSimpleOutputRequest(out);
-
    // Get default parameter to be plotted
    //ParamInfo* parInfo = plotVariable(params);
    //if ( !parInfo )
    //   return false;
 
    // Create netCDF data request
-   // Get action mode
-   string actionMode = this->actionMode();
-//(actionMode == "analyse" || actionMode == "prepare") )
-//verb = "NETCDF";
-
    MvRequest ncDataReq("NETCDF");
    ncDataReq("PATH") = this->ncFileName().c_str();
    ncDataReq("TEMPORARY") = 1;
@@ -371,10 +358,12 @@ bool BufrThermo::createOutputRequest(MvRequest& out)
    gReq("GRAPH_MISSING_DATA_THICKNESS") = 8;
    gReq("_CLASS") = "MGRAPH";
    gReq("_MODULEID") = thermoId;
+   gReq("_SKIP_MACRO") = 1;  // skip macro converter
    MvRequest dataReq = dReq + gReq;
 
    // Create Dewpoint output request
    dReq("NETCDF_X_VARIABLE") = sDEWPOINT.c_str();
+   dReq("_SKIP_MACRO") = 1;  // skip macro converter
 
    gReq("GRAPH_LINE_STYLE") = "dash",
    gReq("GRAPH_MISSING_DATA_STYLE") = "dash";
@@ -387,15 +376,21 @@ bool BufrThermo::createOutputRequest(MvRequest& out)
    wdReq("NETCDF_X_COMPONENT_VARIABLE") = sU.c_str();
    wdReq("NETCDF_Y_COMPONENT_VARIABLE") = sV.c_str();
    wdReq("_MODULEID") = thermoId;
+   wdReq("_SKIP_MACRO") = 1;  // skip macro converter
 
    MvRequest wReq("MWIND");
    wReq("WIND_FIELD_TYPE")  = "flags";
    wReq("WIND_FLAG_COLOUR") = "black";
    wReq("_CLASS") = "MWIND";
    wReq("_MODULEID") = thermoId;
+   wReq("_SKIP_MACRO") = 1;  // skip macro converter
 
    dataReq = dataReq + dReq + gReq + wdReq + wReq;
 
+   // Add information to help the Macro Converter to translate
+   // the output request to a Macro code
+   dataReq("_ORIGINAL_REQUEST") = this->buildMacroConverterRequest();
+
    // Create a default ThermoView request
    MvRequest viewReq("THERMOVIEW");
    //viewReq("X_AUTOMATIC") = "on";  //Not working 20140304, Sylvie is going to fixed.
@@ -403,21 +398,6 @@ bool BufrThermo::createOutputRequest(MvRequest& out)
    viewReq("MAXIMUM_TEMPERATURE") = -40;
    viewReq("_MODULEID") = thermoId;
 
-   // If action is not visualisation related then return the netcdf data.
-   // Also, add the visualisation and original requests as hidden parameters.
-   // These may be used later to help the visualisation of the netcdf data.
-   if ( !this->isVisualise() )
-   {
-      out = ncDataReq;
-      out("_VIEW") = "THERMOVIEW";
-      out("_VISUALISE") = dataReq;
-      out("_CARTESIANVIEW") = viewReq;
-      out("_ORIGINAL_REQUEST") = origReq_;
-      out("_MODULEID") = thermoId;
-
-      return true;
-   }
-
    // Add title information.
    // It must be positioned before the Data+Visdef set of requests to avoid the
    // following problem in uPlot: if another visdef (MGRAPH or MWIND) is defined
@@ -427,6 +407,21 @@ bool BufrThermo::createOutputRequest(MvRequest& out)
    titleReq("TEXT_LINE_1") = this->title().c_str();
    titleReq("TEXT_FONT_SIZE") = 0.5;
    titleReq("_MODULEID") = thermoId;
+   titleReq("_SKIP_MACRO") = 1;  // skip macro converter
+
+   // If action is not visualisation related then return the netcdf data.
+   // Also, add the visualisation and original requests as hidden parameters.
+   // These may be used later to help the visualisation of the netcdf data.
+   if ( !this->isVisualise() )
+   {
+      out = ncDataReq;
+      out("_VIEW") = "THERMOVIEW";
+      out("_VISUALISE") = titleReq + dataReq;
+      out("_VIEW_REQUEST") = viewReq;
+      out("_MODULEID") = thermoId;
+
+      return true;
+   }
 
    // Final output request
    out = viewReq + titleReq + dataReq;
