@@ -43,7 +43,7 @@ public:
    bool generateData( ApplicationInfo&, ParamMap&, MvNetCDF&, MvField&, const string& );
 
    // Create output request
-   MvRequest createOutputRequest( ApplicationInfo&, string, ParamInfo* );
+   MvRequest createOutputRequest( ApplicationInfo&, ParamInfo* );
 
    int computeGeographicalPoints( ApplicationInfo&, MvField* = 0 );
 
