@@ -120,7 +120,7 @@ bool Xsect::processData( MvRequest& data, ApplicationInfo& appInfo, MvRequest& o
       iparam = rq("PARAM");
       const char *lev = rq("LEVELIST");
       istep  = rq("STEP");
-      idate  = rq("DATE");
+      idate  = rq.getBaseDate();
       itime  = rq("TIME");
       expver = rq("EXPVER");
       isML = field.isModelLevel();
@@ -279,7 +279,7 @@ bool Xsect::processData( MvRequest& data, ApplicationInfo& appInfo, MvRequest& o
       currentGenerated++;
       MvRequest r = field.getRequest();
       iparam = r("PARAM");
-      idate  = r("DATE");
+      idate  = r.getBaseDate();
       itime  = r("TIME");
       istep  = r("STEP");
       expver = r("EXPVER");
