@@ -92,6 +92,10 @@ typedef struct dhsdata {
 	mars_grib_index* head_idx;
 	mars_grib_index* tail_idx;
 
+	boolean          mars2mars;
+	request*         othermars;
+	long             expect;
+
 } dhsdata;
 
 static option opts[] = {
@@ -2305,6 +2309,10 @@ static err dhs_send(dhsdata *dhs,request *r,request *e)
 	/* send id */
 	stream_write_ulonglong(&dhs->s,0);
 
+	if(dhs->mars2mars) {
+		set_value(r, "_expect", "%d", dhs->expect);
+	}
+
 	/* Send requests */
 
 	send_request(&dhs->s,r);
@@ -2323,15 +2331,36 @@ static err dhs_send(dhsdata *dhs,request *r,request *e)
 
 	/* Send datahandle */
 
-	stream_write_start(&dhs->s,"MarsHandle");
+	if(dhs->mars2mars) {
+		request* req = empty_request("RETRIEVE");
+		stream_write_start(&dhs->s,"Mars2MarsHandle");
 
-	stream_write_string(&dhs->s,addr);
-	stream_write_int(&dhs->s,port);
-	stream_write_ulonglong(&dhs->s,dhs->id);
+		
+		reqcpy_no_underscores(req, r);
+		send_request(&dhs->s, req);
+		free_all_requests(req);
 
-	stream_write_int(&dhs->s,mars.crc);
+		send_request(&dhs->s, dhs->othermars);
+
+		stream_write_string(&dhs->s, no_quotes(get_value(r, "SOURCE", 0)) + 7);
+
+		stream_write_end(&dhs->s);
+
+	}
+	else {
+
+		stream_write_start(&dhs->s,"MarsHandle");
+
+		stream_write_string(&dhs->s,addr);
+		stream_write_int(&dhs->s,port);
+		stream_write_ulonglong(&dhs->s,dhs->id);
+
+		stream_write_int(&dhs->s,mars.crc);
+
+		stream_write_end(&dhs->s);
+
+	}
 
-	stream_write_end(&dhs->s);
 
 	stream_write_end(&dhs->s);
 
@@ -2438,65 +2467,110 @@ static err  dhs_open(void *data,request *r,request *e,int mode)
 			return -5;
 		}
 
-		if((error = sanity_check(dhs->req)) != NOERR)
-			return error;
+		if(strncmp(s, "mars://", 7) == 0) {
 
-		if((error = check_file_sizes(dhs->req) != NOERR))
-			return error;
+			request *setup = mars.setup;
 
-		if(observation(r))
-		{
-			if((error = dhs_obs_check(dhs,r)))
-				return error;
-		}
-		/* Images should be checked as other GRIB, from grib_api 1.10.0 */
-		else if (image(r))
-		{
-			if( (error = dhs_image_check(dhs)) )
-				return error;
-		}
-		else if (feedback(r))
-		{
-			if( (error = dhs_fb_check(dhs,r)) )
-				return error;
-		}
-		else if (bias(r))
-		{
-			if( (error = dhs_bias_check(dhs,r)) )
-				return error;
-		}
-		else if (track(r))
-		{
-			if( (error = dhs_track_check(dhs,r)) )
-				return error;
-		}
-		else if (is_odb(r))
-		{
-			if( (error = dhs_odb_check(dhs,r)) )
-				return error;
-		}
-		else
-		{
-			if( (error = dhs_grib_check(dhs,r)) )
-				return error;
-		}
+			dhs->expect = count_fields(r);
+			marslog(LOG_INFO,"Using MARS to MARS third party transfer, archiving %ld field(s)", dhs->expect);
+			if(count_values(r, "SOURCE") != 1) {
+				marslog(LOG_EROR,"Multi-source not supported for third party transfer");
+				return -5;
+			}
+
+            while(setup && !dhs->othermars) {
+                int i;
+                for(i=0; i<count_values(setup,"name"); i++) {
+                    if(EQ(get_value(setup, "name", i), s+7)) {
+                        dhs->othermars = setup;
+                    }
+                }
+				setup = setup->next;
+			}
+
+			if(!dhs->othermars || !EQ(get_value(dhs->othermars,"class", 0), "dhsbase")) {
+				marslog(LOG_EROR, "Invalid database for third party transfer: %s", s+7);
+				marslog(LOG_EROR, "Possible values are:");
+				setup = mars.setup;
+				while(setup) {
+					if(EQ(get_value(setup, "class", 0), "dhsbase")) {
+                        int i;
+                        for(i=0; i<count_values(setup,"name"); i++) {
+                            marslog(LOG_EROR, "  %s", get_value(setup, "name", i));
+                        }
+					}
+					setup = setup->next;
+				}
+				return -5;
+			}
+
+
+			dhs->mars2mars = true;
 
-		if(getenv("MARS_NO_ARCH"))
-		{
-			marslog(LOG_WARN,"'MARS_NO_ARCH' selected. Skipping archive");
-			dhs->finished = true;
-			return 0;
 		}
+		else {
 
-		if(!mars.fields_are_ok)
-		{
-			FILE *f = mail_open(mars.dhsmail,"Mars ARCHIVE failure (dhsbase)");
-			mail_request(f,"MARS Request:",r);
-			mail_request(f,"MARS Environment:",e);
-			mail_close(f);
+			if((error = sanity_check(dhs->req)) != NOERR)
+				return error;
+
+			if((error = check_file_sizes(dhs->req) != NOERR))
+				return error;
+
+			if(observation(r))
+			{
+				if((error = dhs_obs_check(dhs,r)))
+					return error;
+			}
+			/* Images should be checked as other GRIB, from grib_api 1.10.0 */
+			else if (image(r))
+			{
+				if( (error = dhs_image_check(dhs)) )
+					return error;
+			}
+			else if (feedback(r))
+			{
+				if( (error = dhs_fb_check(dhs,r)) )
+					return error;
+			}
+			else if (bias(r))
+			{
+				if( (error = dhs_bias_check(dhs,r)) )
+					return error;
+			}
+			else if (track(r))
+			{
+				if( (error = dhs_track_check(dhs,r)) )
+					return error;
+			}
+			else if (is_odb(r))
+			{
+				if( (error = dhs_odb_check(dhs,r)) )
+					return error;
+			}
+			else
+			{
+				if( (error = dhs_grib_check(dhs,r)) )
+					return error;
+			}
+
+			if(getenv("MARS_NO_ARCH"))
+			{
+				marslog(LOG_WARN,"'MARS_NO_ARCH' selected. Skipping archive");
+				dhs->finished = true;
+				return 0;
+			}
+
+			if(!mars.fields_are_ok)
+			{
+				FILE *f = mail_open(mars.dhsmail,"Mars ARCHIVE failure (dhsbase)");
+				mail_request(f,"MARS Request:",r);
+				mail_request(f,"MARS Environment:",e);
+				mail_close(f);
+
+				marslog(LOG_EROR,"Some of the fields are rejected by the new mars server");
+				return -1;
+			}
 
-			marslog(LOG_EROR,"Some of the fields are rejected by the new mars server");
-			return -1;
 		}
 
 	}
