@@ -244,7 +244,7 @@ request *get_environ(void)
 
 	if(env) return env;
 
-	if(EQ(who,"bamboo") || EQ(who,"deploy"))
+	if(EQ(who,"bamboo") || EQ(who,"deploy") || (EQ(who,"worker") && !mars.marslite_mode) )
 		who = user("max");
 
 	if(useTest && EQ(who,"max"))
