@@ -361,8 +361,7 @@ err pparea(request *r)
 	if( p = get_value(r,"_AREA_W",0)) w_  =  w  = atof(p);
 	if( p = get_value(r,"_GRID_EW",0))ew_ =  ew = atof(p);
 	if( p = get_value(r,"_GRID_NS",0))ns_ =  ns = atof(p);
-	if( p = get_value(r,"_GAUSSIAN",0)) ew_ =  ew = atof(p);
-
+    if( p = get_value(r,"_GAUSSIAN",0)) ew_ =  ew = atof(p);
 
 	if(ew == 0 && ns == 0)
 		return 0;
@@ -376,7 +375,7 @@ err pparea(request *r)
 	}
 		
 
-	if(ew_ != 0 && ew_ != ew || ns_ != ns)
+	if( ((ew_ != 0) && (ew_ != ew)) || (ns_ != ns) )
 	{
 		if(ns == 0)
 		{
@@ -631,6 +630,9 @@ err vector_postproc(ppbuffer_t *pp, long *nbuffer)
 		char *pufield = (p<q)?pair[p].buffer:pair[q].buffer;
 		char *pvfield = (p<q)?pair[q].buffer:pair[p].buffer;
 
+		size_t u_len = (p<q)?pair[p].len:pair[q].len;
+		size_t v_len = (p<q)?pair[q].len:pair[p].len;
+
 		fortint   out = pp[0].buflen;
 
 		marslog(LOG_DBUG,"Got parameters %d and %d. Calling vector post-processing",p,q);
@@ -658,8 +660,10 @@ err vector_postproc(ppbuffer_t *pp, long *nbuffer)
 		if(mars.use_intuvp && is_wind(p) && (ppdata.derive_uv > 0))
 		{
 			marslog(LOG_DBUG,"MARS_USE_INTUVP set and parameters are U/V. Avoid calling intvect_");
-			memcpy(pp[0].buffer,pufield,pp[0].inlen);
-			memcpy(pp[1].buffer,pvfield,pp[0].inlen);
+			memcpy(pp[0].buffer, pufield, u_len);
+			pp[0].inlen = u_len;
+			memcpy(pp[1].buffer, pvfield, v_len);
+			pp[1].inlen = v_len;
 			out=0;
 			/* ppdata.inter_cnt+=2; */
 			ret=0;
@@ -694,7 +698,8 @@ err vector_postproc(ppbuffer_t *pp, long *nbuffer)
 
 		if(out == 0)
 		{
-			pp[0].outlen = pp[1].outlen = pp[0].inlen;
+			pp[0].outlen = pp[0].inlen;
+			pp[1].outlen = pp[1].inlen;
 		}
 		else {
 			pp[0].outlen = pp[1].outlen = out;
@@ -1399,7 +1404,7 @@ err ppinit(const request *r, postproc *proc)
 	ppdata.dup_count = 0;
 #endif
 
-	if(p = get_value(r,"GRIB",0))
+	if( (p = get_value(r,"GRIB",0)) )
 	{
 		ppdata.original_grib = EQ(p,"ORIGINAL");
 	}
@@ -1447,7 +1452,7 @@ err ppinit(const request *r, postproc *proc)
 
 		if(ppdata.idents) FREE(ppdata.idents);
 
-		if(ppdata.ident_cnt = count_values(r,"IDENT"))
+		if( (ppdata.ident_cnt = count_values(r,"IDENT")) )
 			ppdata.idents = NEW_ARRAY(int,ppdata.ident_cnt);
 
 		for(i = 0;i<ppdata.ident_cnt;i++)
@@ -1478,7 +1483,7 @@ err ppinit(const request *r, postproc *proc)
 
 		if(ppdata.types) FREE(ppdata.types);
 
-		if(ppdata.type_cnt = count_values(r,"OBSTYPE"))
+		if( (ppdata.type_cnt = count_values(r,"OBSTYPE")) )
 		{
 			int zero = 0;
 			ppdata.types = NEW_ARRAY(int,ppdata.type_cnt);
@@ -1550,7 +1555,7 @@ err ppinit(const request *r, postproc *proc)
 
 		if(ppdata.idents) FREE(ppdata.idents);
 
-		if(ppdata.ident_cnt = count_values(r,"IDENT"))
+		if( (ppdata.ident_cnt = count_values(r,"IDENT")) )
 			ppdata.idents = NEW_ARRAY(int,ppdata.ident_cnt);
 
 		for(i = 0;i<ppdata.ident_cnt;i++)
@@ -1581,7 +1586,7 @@ err ppinit(const request *r, postproc *proc)
 		/* Instruments */
 		if(ppdata.instruments) FREE(ppdata.instruments);
 
-		if(ppdata.instrument_cnt = count_values(r,"INSTRUMENT"))
+		if( (ppdata.instrument_cnt = count_values(r,"INSTRUMENT")) )
 			ppdata.instruments = NEW_ARRAY(fortint,ppdata.instrument_cnt);
 
 		for(i = 0;i<ppdata.instrument_cnt;i++)
@@ -1591,7 +1596,7 @@ err ppinit(const request *r, postproc *proc)
 
 		if(ppdata.types) FREE(ppdata.types);
 
-		if(ppdata.type_cnt = count_values(r,"OBSTYPE"))
+		if( (ppdata.type_cnt = count_values(r,"OBSTYPE")) )
 		{
 			int zero = 0;
 			ppdata.types = NEW_ARRAY(int,ppdata.type_cnt);
@@ -1615,7 +1620,7 @@ err ppinit(const request *r, postproc *proc)
 
 		if(ppdata.blocks) FREE(ppdata.blocks);
 
-		if(ppdata.block_cnt = count_values(r,"BLOCK"))
+		if( (ppdata.block_cnt = count_values(r,"BLOCK")) )
 			ppdata.blocks = NEW_ARRAY(int,ppdata.block_cnt);
 
 		for(i = 0;i<ppdata.block_cnt;i++)
@@ -1712,7 +1717,7 @@ err ppinit(const request *r, postproc *proc)
 
 		/* By default, copy edition from intput to output: edition=0*/
 		ppdata.edition = 0;
-		if(p = get_value(r,"FORMAT",0))
+		if( (p = get_value(r,"FORMAT",0)) )
 		{
 			if(EQ(p,"GRIB1")) ppdata.edition = 1;	
 			if(EQ(p,"GRIB2")) ppdata.edition = 2;	
@@ -1729,7 +1734,21 @@ err ppinit(const request *r, postproc *proc)
 
 		}
 
-		/* set grid */
+        /* gridname */
+
+        const char *gridname = get_value(r,"_GRIDNAME",0);
+        if(gridname)
+        {
+            ret = ppout("gridname",n,array,gridname);
+            if(ret) return ret;
+
+            n = atoi(get_value(r,"_GAUSSIAN",0));
+            long guess;
+            guess = (2*n) * (4*n+20); /* nb lats * nb points at equator for octahedral grid */
+            if( guess > ppdata.estimate ) ppdata.estimate = guess;
+        }
+
+        /* set LatLon grid */
 
 		if(get_value(r,"_GRID_EW",0))
 		{
@@ -1777,36 +1796,7 @@ err ppinit(const request *r, postproc *proc)
 			if(ret) return ret;
 		}
 
-		/* gaussian */
-
-		if(get_value(r,"_GAUSSIAN",0))
-		{
-			long guess;
-			const char *gaussian = "GAUSSIAN";
-			const char *g = get_value(r,"GAUSSIAN",0);
-			const char *oldgauss = getenv("MARS_REGULAR_GRID");
-
-			if(g != NULL)
-			{
-				gaussian = g;
-			}
-
-			n    = atoi(get_value(r,"_GAUSSIAN",0));
-
-			if(oldgauss && atoi(oldgauss))
-			{
-				gaussian  = "REGULAR";
-				marslog(LOG_WARN,"Please, specify new keyword ");
-				marslog(LOG_WARN,"GAUSSIAN=REGULAR in your request");
-			}
-
-			ret  = ppout((char *)lowcase(gaussian),n,array,0);
-			if(ret) return ret;
-			guess = n * n * 8;
-			if( guess > ppdata.estimate ) ppdata.estimate = guess;
-		}
-
-		/* Interpolation */
+        /* Interpolation */
 		
 		if(get_value(r,"INTERPOLATION",0))
 		{
@@ -1847,14 +1837,14 @@ err ppinit(const request *r, postproc *proc)
 						if(ret) marslog(LOG_EROR,"Auto Resolution error %d",ret);
 					}
 				}
-				if(trunc[0] == 'N')
-				{
-					n    = atoi(trunc+1);
-					marslog(LOG_DBUG,"Using GG double interpolation to %d",n);
-					ret = ppout("intermediate_gaussian",n,array,0);
-					if(ret) marslog(LOG_EROR,"Double interpolation error %d",ret);
-				}
-			}
+                if(trunc[0] == 'N' || trunc[0] == 'O')
+                {
+                    n    = atoi(trunc+1);
+                    marslog(LOG_DBUG,"Using GG double interpolation to %s", trunc);
+                    ret = ppout("intermediate_gaussian",n,array,trunc);
+                    if(ret) marslog(LOG_EROR,"Double interpolation error %d",ret);
+                }
+            }
 
 		}
 
@@ -2005,7 +1995,7 @@ fieldset *pp_fieldset(const char *file,request *filter)
 	postproc proc;
 
 	if(!v) return NULL;
-	if(e = ppinit(filter,&proc)) {
+	if( (e = ppinit(filter,&proc)) ) {
 		marslog(LOG_EROR,"Interpolation initialisation failed (%d)",e);
 		ppdone();
 		return NULL;
