@@ -122,7 +122,12 @@ long64 proc_mem()
 
 long64 proc_mem()
 {
-	return 0;
+    struct rusage rup;
+
+    if(getrusage(RUSAGE_SELF,&rup) != -1)
+        return rup.ru_maxrss*1024;
+
+    return 0;
 }
 
 #endif
