@@ -1688,7 +1688,7 @@ double MvField::yyyymmddFoh()
 
 	return 0;               //-- failed to extract date
 #endif
-	double dat = mvgrid_->getDouble("date");
+	double dat = mvgrid_->getDouble("dataDate");
 	double tim = mvgrid_->getDouble("time");
 
 	//nontested_grib_api_port("MvField::yyyymmddFoh()");
