@@ -1480,6 +1480,9 @@ MvLambertGrid::MvLambertGrid( field* myfield
        return;
    }
 
+   long jPositive = getLong("jScansPositively");      //-- points scan in +j dir
+   jPositive_ = (jPositive == 1);
+
    earthRadius_ = cEarthRadius;
 
    gridTanLat_ = getDouble("Latin1InDegrees") * 1000; // sec2_[cInterSecLat1];
@@ -1510,7 +1513,7 @@ MvLambertGrid::MvLambertGrid( field* myfield
    }
 
    earthRadiusPerDx_ = earthRadius_ / dx_;
-   cout << "R, dx, R/dx:\t" << earthRadius_ << "\t" << dx_ << "\t" << earthRadiusPerDx_ << endl;
+   //cout << "R, dx, R/dx:\t" << earthRadius_ << "\t" << dx_ << "\t" << earthRadiusPerDx_ << endl;
 
    hemiSphere_ = gridTanLat_ > 0 ? 1 : 0;
    gridTanLat_ = (gridTanLat_ / cGridScaling) * cToRadians;  //--aki cGridScaling--//
@@ -1613,7 +1616,7 @@ MvLambertGrid::computeLatLon( int ip, int jp )
 //--   PRGMMR: STACKPOLE        ORG: NMC42       DATE:88-11-28
 
     double XX = (double)ip - poleI_;
-    double YY = poleJ_ - (double)jp;
+    double YY = (jPositive_) ? poleJ_ - (double)jp : poleJ_ - (double)(1+horisLines_-jp);
     double R2 = XX*XX + YY*YY;
 //
 //        CHECK THAT THE REQUESTED I,J IS NOT IN THE FORBIDDEN ZONE
