@@ -940,15 +940,30 @@ bool MvRequest::getPath(const char* par,string &resPath,bool canBeEmpty,string &
 			if(callerIcon)
 			{
 	  			string callerDir(callerIcon);	  	
-                char *mvudir=getenv("METVIEW_USER_DIRECTORY");
-                if(mvudir)
+
+				// special case: if callerDir is a path with "Process@" in it, then it
+				// very probably means that this was run from a macro - in this case, we can't
+				// use the returned path (because it's invalid) and instead a relative path should be
+				// considred relative to where the macro is run from; so in this case we would simply
+				// remove the path.
+
+				if(callerDir.find("Process@") != string::npos)
 				{
-	  				callerDir=string(mvudir) + "/" + callerDir;
-				}	
-				string::size_type pos=callerDir.find_last_of("/");
-	 			if(pos != string::npos)
+					// yes, it's called from Macro - files are relative to current dir
+					callerDir = ".";
+				}
+				else
 				{
-		 			callerDir=callerDir.substr(0,pos);
+					char *mvudir=getenv("METVIEW_USER_DIRECTORY");
+					if(mvudir)
+					{
+						callerDir=string(mvudir) + "/" + callerDir;
+					}	
+					string::size_type pos=callerDir.find_last_of("/");
+	 				if(pos != string::npos)
+					{
+		 				callerDir=callerDir.substr(0,pos);
+					}
 				}
 					
 				resPath=callerDir + "/" + resPath;
@@ -995,8 +1010,23 @@ bool MvRequest::getPath(const char* iconPar,const char* textPar,string &resPath,
 	
 	return true;
 }	
-  
-  
+
+
+
+// MvRequest::getBaseDate()
+// returns zero if neither HDATE nor DATE are present in the request
+int MvRequest::getBaseDate()
+{
+    int date = (*this)("HDATE");  // try HDATE first (will return 0 if not there)
+
+    if (date == 0)
+        date = (*this)("DATE");   // no HDATE? try DATE (will return 0 if not there)
+
+    return date;
+}
+
+
+
 bool MvRequest::getValueId(const char* par,string& value,const std::map<string,string>& idMap,bool canBeEmpty,string &errTxt)
 {	
         value.clear();
