@@ -584,13 +584,18 @@ public:
 	MvRequest ExpandRequest ( const char*, const char*, long );
 	
 	
+	//  Get the base date from the request (specific to request from GRIB data)
+	int getBaseDate();
+
 	//Find out path (it can be relative path as well) stored in parameter par.
 	bool getPath(const char* par,string& resPath,bool canBeEmpty,string &errTxt);
 	bool getPath(const char* iconPar,const char* textPar,string &resPath,bool canBeEmpty,string &errTxt);
 	bool getValueId(const char* par,string& value,const std::map<string,string>& idMap,bool canBeEmpty,string &errTxt);
 	bool getValue(const char* par,string& value,bool canBeEmpty,string &errTxt);
 	bool getValue(const char* par,std::vector<string>& value,bool canBeEmpty,string &errTxt);
-	
+
+   // Check if the input request has the same contents given a set of parameters
+   bool checkParameters( MvRequest&, std::vector<string>& );
 };
 
 //! Convenience class (not used currently)
