@@ -431,8 +431,8 @@ void GribMvDump::read(const string& fgrib, int count)
 	
 	stringstream in, cnt_s;
 
-	vector<char*> name_space;
-	name_space.push_back(0);
+	vector<std::string> name_space;
+	name_space.push_back("Default");
 	name_space.push_back("geography");
 	name_space.push_back("ls");
 	name_space.push_back("mars");
@@ -444,7 +444,7 @@ void GribMvDump::read(const string& fgrib, int count)
 	// list of blacklisted keys - these can be very expensive to compute; we can
 	// always put them back in if someone really really needs them...
 	// to be considered: minimum, maximum
-	vector<string> key_blacklist;
+	vector<std::string> key_blacklist;
 	key_blacklist.push_back("distinctLatitudes");
 	key_blacklist.push_back("distinctLongitudes");
 	key_blacklist.push_back("distinctLatitudes");
@@ -491,24 +491,37 @@ void GribMvDump::read(const string& fgrib, int count)
   	}
 
 	//Get messages form the file
-  	while((gh = grib_handle_new_from_file(0,fp,&err)) != NULL)
+  	while((gh = grib_handle_new_from_file(0,fp,&err)) != NULL || err != GRIB_SUCCESS)
 	 {
 		grib_count++;
 
-		if(!gh) 
-		{
-      			log->error("GribMvDump::read() ---> Unable to create grib handle\n");
-      			return;
-    		}
+		//if(!gh) 
+		//{
+      		//	log->error("GribMvDump::read() ---> Unable to create grib handle\n");
+      		//	return;
+    		//}
 
 		if(grib_count == count)
 		{
    			//cout << "-- GRIB N. " << grib_count << "---/n";
     			
+			if(!gh) 
+			{
+      				stringstream err_s;
+				err_s << "GribMvDump::read() ---> Unable to create grib handle for message no: " <<
+                                                 grib_count << "\n";
+				log->error(err_s.str());	
+      				return;
+			}
+				
 			for(unsigned int ns = 0 ; ns  < name_space.size(); ns++)
 			{
    				//Get key iterator
-				kiter=grib_keys_iterator_new(gh,key_iterator_filter_flags,name_space[ns]);
+				if (name_space[ns]!="Default")
+					kiter=grib_keys_iterator_new(gh,key_iterator_filter_flags,const_cast<char *>(name_space[ns].c_str()));
+				else
+					kiter=grib_keys_iterator_new(gh,key_iterator_filter_flags,NULL);
+
 				if (!kiter)
 				{
 					stringstream err_s;
@@ -538,9 +551,9 @@ void GribMvDump::read(const string& fgrib, int count)
 
 
 					//Add namespace prefix to the key name (e.g. mars.param)
-					if(name_space[ns] != 0)
+					if(name_space[ns] != "Default")
 					{
-						cbuff = string(name_space[ns]) + "." + cbuff;				
+						cbuff = name_space[ns] + "." + cbuff;				
 					}
 					
 					//Get string value
@@ -597,7 +610,8 @@ void GribMvDump::read(const string& fgrib, int count)
 			break;			
 		}
 
-		grib_handle_delete(gh);
+		if(gh)
+			grib_handle_delete(gh);
   	}
 }
 
@@ -679,19 +693,29 @@ void GribValueDump::read(const string& fgrib, int count)
   	}
 
 	//Get messages form the file
-  	while((gh = grib_handle_new_from_file(0,fp,&err)) != NULL && grib_count < count)
+  	while(((gh = grib_handle_new_from_file(0,fp,&err)) != NULL || err != GRIB_SUCCESS) && grib_count < count)
 	 {
 		grib_count++;
 
-		if(!gh) 
-		{
-      			log->error("GribValueDump::read() ---> Unable to create grib handle\n");
-      			return;
-    		}
+		//if(!gh) 
+		//{
+      		//	log->error("GribValueDump::read() ---> Unable to create grib handle\n");
+      		//	return;
+    		//}
 
 		if(grib_count == count)
 		{
-   			size_t latNum, lonNum, valNum;
+
+		  	if(!gh) 
+			{
+      				stringstream err_s;
+				err_s << "GribValueDump::read() ---> Unable to create grib handle for message no: " <<
+                                                 grib_count << "\n";
+				log->error(err_s.str());
+				return;
+    			}		  
+		  
+		  	size_t latNum, lonNum, valNum;
 			string latName, lonName;
 			
 			//cout << "-- GRIB N. " << grib_count << "---/n";
@@ -824,7 +848,8 @@ void GribValueDump::read(const string& fgrib, int count)
 				
 		}
 		
-		grib_handle_delete(gh);
+		if(gh)
+			grib_handle_delete(gh);
   	}
 	
 	fclose(fp);
@@ -873,7 +898,7 @@ GribMetaData::~GribMetaData()
 {
 }
 
-void GribMetaData::setFilter(vector<file_offset> offset, vector<int> len)
+void GribMetaData::setFilter(vector<off_t> offset, vector<int> len)
 {
 	filterOffset_=offset;
 	filterLen_=len;
@@ -984,48 +1009,49 @@ void GribMetaData::readMessages(MvKeyProfile *prof)
 	//For filtered datasets
 	if(filterEnabled_==true)
 	{					
-		//At the first scan we need o find the message cnt for each filtered message.
+		//At the first scan we need to find the message cnt for each filtered message.
 		//The goal is to fill up the filterCnt_ vector.
 		if(firstScan_)
 		{
 			//long currentOffset=0;
 			int msgCnt=0;
-			while((gh = grib_handle_new_from_file(0,fp,&err)) != NULL)
+			while((gh = grib_handle_new_from_file(0,fp,&err)) != NULL || err != GRIB_SUCCESS)
 	 		{
-    			if(!gh) 
+    				if(!gh) 
 				{
-      				stringstream sst;
+      					stringstream sst;
 					sst <<  "GribMetaData::readMessages() --->  Unable to create grib handle for message count: " << grib_count+1;
 					log->error(sst.str());
-      				return;
-    			}
+    				}
 				
 				msgCnt++;
 
-				if(grib_get_long(gh,"offset",&longValue) == GRIB_SUCCESS)
-				{
-					for(unsigned int i=0; i < filterOffset_.size(); i++)
+				if(gh)
+				{  
+					if(grib_get_long(gh,"offset",&longValue) == GRIB_SUCCESS)
 					{
-						file_offset offset_diff = longValue - filterOffset_[i];
-						if(ABS(offset_diff) < 120)
+						for(unsigned int i=0; i < filterOffset_.size(); i++)
 						{
-							filterCnt_[i] = msgCnt;
-							break;
+							off_t offset_diff = longValue - filterOffset_[i];
+							if(ABS(offset_diff) < 120)
+							{
+								filterCnt_[i] = msgCnt;
+								break;
+							}
 						}
 					}
-				}
-				else
-				{
-					stringstream sst;
-					sst <<  "GribMetaData::readMessages() --->  Cannot get offset for message count: " << grib_count+1;
-					log->error(sst.str());
-      				grib_handle_delete(gh);
-					return;
+					else
+					{
+						stringstream sst;
+						sst <<  "GribMetaData::readMessages() --->  Cannot get offset for message count: " << grib_count+1;
+						log->error(sst.str());
+      						grib_handle_delete(gh);
+						return;
+					}
 
-				}
-
-				//currentOffset+=longValue;
-				grib_handle_delete(gh);
+					//currentOffset+=longValue;
+					grib_handle_delete(gh);
+				}	
 			}
 		}
 		
@@ -1044,27 +1070,29 @@ void GribMetaData::readMessages(MvKeyProfile *prof)
 				stringstream sst;
 				sst <<  "GribMetaData::readMessages() --->  Unable to create grib handle for offset: " << filterOffset_[i];
 				log->error(sst.str());
-				return;
+				//return;
 			}
 				
 			readMessage(prof,gh);
 	
 			observer_->messageScanStepChanged(grib_count);
-	
-			grib_handle_delete(gh);
+						
+			if(gh)
+				grib_handle_delete(gh);
 		}	
 	}	
 	else
-	{
+	{	  
 		//Get messages form the file
-  		while((gh = grib_handle_new_from_file(0,fp,&err)) != NULL)
+  		while((gh = grib_handle_new_from_file(0,fp,&err)) != NULL || err != GRIB_SUCCESS)
 	 	{
     			if(!gh) 
 			{
       				stringstream sst;
-				sst <<  "GribMetaData::readMessages() --->  Unable to create grib handle for message count: " << grib_count+1;
+				sst <<  "GribMetaData::readMessages() --->  Unable to create grib handle for message count: " << grib_count+1 << endl;
 				log->error(sst.str());
-      				return;
+      				//return;
+				//continue;
     			}
 		
 			grib_count++;
@@ -1072,16 +1100,19 @@ void GribMetaData::readMessages(MvKeyProfile *prof)
 			readMessage(prof,gh);
 
 			observer_->messageScanStepChanged(grib_count);
-	
-			grib_handle_delete(gh);
+			
+			if(gh) 
+				grib_handle_delete(gh);
 		}
 
 		if(firstScan_)
 		{
 			if(totalMessageNum_ != grib_count)
 			{
-			  	totalMessageNum_=grib_count;
-			  	hasMultiMessage_=true;	
+				if(totalMessageNum_ != 0)
+				  	hasMultiMessage_=true;
+			  	
+				totalMessageNum_=grib_count;			  	
 			}
 		}
 	}
@@ -1221,20 +1252,36 @@ void GribMetaData::getKeyList(int count,string nameSpace,list<string> &keys)
   	}
 
 	//Get messages form the file
-  	while((gh = grib_handle_new_from_file(0,fp,&err)) != NULL)
+  	while((gh = grib_handle_new_from_file(0,fp,&err)) != NULL || err != GRIB_SUCCESS)
 	 {
 		grib_count++;
 
-		if(!gh) 
+		/*if(!gh) 
 		{
       			log->error("GribMetaData::getKeyList() ---> Unable to create grib handle\n");
       			return;
-    		}
+    		}*/
 
 		if(grib_count == count)
 		{
    			//cout << "-- GRIB N. " << grib_count << "---/n";
     			
+			if(!gh) 
+			{
+      				stringstream err_s;
+				err_s << "GribMetaData::getKeyList() ---> Unable to create grib handle for message no: " <<
+                                                 grib_count << "\n";
+				log->error(err_s.str());		 
+      				
+				for(vector<char*>::iterator it=nameSpaceL.begin(); it != nameSpaceL.end(); it++)
+				{
+					if((*it) != 0)
+						delete [] *it;
+				}
+				
+				return;
+    			}
+			
 			for(unsigned int ns = 0 ; ns  < nameSpaceL.size(); ns++)
 			{
    				//Get key iterator
@@ -1245,7 +1292,14 @@ void GribMetaData::getKeyList(int count,string nameSpace,list<string> &keys)
 					err_s << "GribMetaData::getKeyList() ---> Unable to create keys iterator for message no: " <<
                                                  grib_count << "\n";
 					log->error(err_s.str());					
-      					return;
+      					
+					for(vector<char*>::iterator it=nameSpaceL.begin(); it != nameSpaceL.end(); it++)
+					{
+						if((*it) != 0)
+							delete [] *it;
+					}
+					
+					return;
     				}
 
 				//Loop for the keys in the current message until all the keys are found
@@ -1293,11 +1347,11 @@ void GribMetaData::getKeyList(int count,string nameSpace,list<string> &keys)
 
 	fclose(fp);
 
-	//To-do: this should be called before calling return in this method!!
+	//This has to be called before calling return in this method!!
 	for(vector<char*>::iterator it=nameSpaceL.begin(); it != nameSpaceL.end(); it++)
 	{
 		if((*it) != 0)
-			delete *it;
+			delete [] *it;
 	}
  
 
@@ -1310,7 +1364,17 @@ long GribMetaData::gribapiVersionNumber()
 
 void GribMetaData::readMessage(MvKeyProfile* prof,grib_handle *gh)
 {
-	const int MAX_VAL_LEN=1024;	
+	
+  	if(!gh)
+	{
+		for(unsigned int i=0; i< prof->size() ; i++ )
+		{	
+			prof->at(i)->addValue("N/A");
+		}
+	  	return;
+	}
+  
+  	const int MAX_VAL_LEN=1024;	
 	long longValue;
 	char value[MAX_VAL_LEN];
 	string svalue;
