@@ -40,6 +40,9 @@ ExportDialog::ExportDialog(int currentFrame, int totalFrames, QWidget *parent) :
     // Set widget mode behaviour to "Save As"
     this->setAcceptMode(QFileDialog::AcceptSave);
 
+    // Setting for Mac OS X 
+    setOption(QFileDialog::DontUseNativeDialog,true);
+
     // Restore previous gui settings
     QSettings settings("ECMWF","uPlotExportDialog");
     settings.beginGroup("main");
@@ -48,7 +51,13 @@ ExportDialog::ExportDialog(int currentFrame, int totalFrames, QWidget *parent) :
     settings.endGroup();
 
     // Set filter options to select which files to be shown
+#ifdef METVIEW_QT5
+    QStringList filters;
+    filters << "All Files (*.*)" << "Images (*.png *.ps *.eps *.jpg *.kml *.gif *.svg *.pdf)";
+    this->setNameFilters(filters);
+#else
     this->setFilter(tr("All Files (*.*);;Images (*.png *.ps *.eps *.jpg *.kml *.gif *.svg *.pdf)"));
+#endif
 
     // Get the main layout
     QGridLayout *mainLayout = static_cast<QGridLayout*>(layout());
@@ -125,6 +134,11 @@ ExportDialog::~ExportDialog()
 // Callback from the SAVE button
 void ExportDialog::accept()
 {
+    // This function is also called if the user selected a filename
+    // from the treeView. If this is the case just continue.
+    if ( sender()->objectName() == "treeView" )
+       return;
+
     // Get filename from the user interface
     QStringList s = selectedFiles();
     string filename = s.at(0).toStdString();
