@@ -1197,37 +1197,53 @@ bool MvIconDataBase::ExistsInRelation ( MvRelation &relation, const int firstId,
 
 void MvIconDataBase::CreateLink (MvRequest& req)
 {
-    // If there is no path, do no create a link
-    const char* mpath = (const char*)(req("PATH"));
-    if ( mpath == 0) return;
+   // If there is no path, do no create a link
+   const char* mpath = (const char*)(req("PATH"));
+   if ( mpath == 0)
+      return;
 
-    // Check if the link has to be created
-    const char* createLink = (const char*)req("_CREATE_LINK");
-    if ( createLink && strcmp(createLink,"NO") == 0 )
-        return;
+   // Check if the link has to be created
+   const char* createLink = (const char*)req("_CREATE_LINK");
+   if ( createLink && strcmp(createLink,"NO") == 0 )
+      return;
 
-    string spath = (const char*)mpath;
-    string slink = tempnam(getenv("METVIEW_TMPDIR"),"link");
+   string spath = (const char*)mpath;
+   string slink = tempnam(getenv("METVIEW_TMPDIR"),"link");
 
-    if ( symlink(spath.c_str(),slink.c_str()) != 0 ) //-- create a soft link
-    {
-        marslog(LOG_WARN,(char*)"MvIconDataBase::CreateLink: unable to create a link");
+   if ( symlink(spath.c_str(),slink.c_str()) != 0 ) //-- create a soft link
+   {
+      marslog(LOG_WARN,(char*)"MvIconDataBase::CreateLink: unable to create a link");
 
-        return; //-- nothing to do => bail out!
-    }
+      return; //-- nothing to do => bail out!
+   }
 
-    //-- make sure that soft link is not a dangling ptr!
-    if( !FileCanBeOpened( slink.c_str(), "r" ) )
-    {
-        marslog(LOG_WARN,(char*)"Created soft link is dangling: %s", slink.c_str());
+   //-- make sure that soft link is not a dangling ptr!
+   bool flag = true;
+   if( !FileCanBeOpened( slink.c_str(), "r" ) )
+   {
+      // Try to use parameter _PATH
+      if ( (const char*)req("_PATH") )
+      {
+         remove(slink.c_str());
+         spath = (const char*)req("_PATH");
+         symlink(spath.c_str(),slink.c_str());
+         if ( !FileCanBeOpened( slink.c_str(), "r" ) )
+            flag = false;
+      }
+      else
+        flag = false;
+   }
+   if ( !flag )
+   {
+      marslog(LOG_WARN,(char*)"Created soft link is dangling: %s", slink.c_str());
 
-        return; //-- nothing to do => bail out!
-    }
+      return; //-- nothing to do => bail out!
+   }
 
-    req("PATH") = slink.c_str();
-    linkList_.push_back(slink.c_str());
+   req("PATH") = slink.c_str();
+   linkList_.push_back(slink.c_str());
 
-    return;
+   return;
 }
 
 void MvIconDataBase::DeleteLink ()
