@@ -92,8 +92,8 @@ ObjectInfo::ConvertRequestToMacro( MvRequest& inRequest,
 			// Can we follow subRequest also ?
 			if ( (const char *)subRequest("_NAME") )
 			{
-				Cached fullName = MakeUserPath(subRequest("_NAME") );
-				if ( FileCanBeOpened(fullName,"r") )
+				string fullName = MakeUserPath((const char*)subRequest("_NAME") );
+				if ( FileCanBeOpened(fullName.c_str(),"r") )
 				{
 					Cached returnName = Convert(subRequest);
 					if ( strcmp(returnName,"") )
@@ -120,22 +120,22 @@ ObjectInfo::ConvertRequestToMacro( MvRequest& inRequest,
 		{
 			// Try to find out if this is a file reference.
 			// We need to get the full path
-			Cached tmpName = value;
+			string tmpName = value;
 			if ( IsParameterSet(inRequest,"_NAME") )
-				tmpName = dirname(inRequest("_NAME")) + Cached("/") + value;
+				tmpName = string(dirname(inRequest("_NAME"))) + "/" + value;
 
-			Cached refName =  MakeUserPath(tmpName);
-			if ( access( refName, R_OK )  == 0 )
+			string refName = MakeUserPath(tmpName);
+			if ( access( refName.c_str(), R_OK )  == 0 )
 			{
 				// If it is a DATA (binary) file, creates a dummy request.
 				// The crucial information needed is parameter _NAME
-				if ( ! IsBinaryOrMissingFile( refName ) )
-					subRequest.read  ( (const char*) refName);
+				if ( ! IsBinaryOrMissingFile(refName.c_str()) )
+					subRequest.read(refName.c_str());
 				else
 					subRequest.setVerb("DATA");
 
 				if ( ! IsParameterSet(subRequest,"_NAME") )
-				subRequest("_NAME") = tmpName;
+				subRequest("_NAME") = tmpName.c_str();
 
 				Cached returnName = Convert(subRequest);
 				if ( strcmp(returnName,"") )
@@ -155,10 +155,10 @@ ObjectInfo::ConvertRequestToMacro( MvRequest& inRequest,
 		// Convert macroName to lower case.
 		char *macrolower = new char[ strlen(macroName) + 1];
 		strcpy(macrolower,macroName);
-
 		for (i = 0; i < (int)strlen(macrolower); i++ )
-		macrolower[i] = tolower(macrolower[i]);
+         macrolower[i] = tolower(macrolower[i]);
 
+      PutNewLine("");
 		PutNewLine( ObjectInfo::SpaceToUnderscore(varName) + Cached(" = ") +  Cached(macrolower) + Cached("(") );
 
 		delete [] macrolower;
@@ -260,13 +260,17 @@ ObjectInfo::ConvertDataUnitToMacro ( MvIcon& dataUnit )
       }
    }
 
-  int use_mode = duRequest("_USE_MODE");
-
-  if ( ! use_mode )
-    objectName = Convert(duRequest);
-
-  else
-    {
+   int use_mode = duRequest("_USE_MODE");
+   if ( ! use_mode )
+   {
+      MvRequest reqAux = duRequest.getSubrequest("_ORIGINAL_REQUEST");
+      if ( reqAux && (const char*)reqAux("_MACRO_DECODE_TAG") )
+         objectName = Convert(reqAux);
+      else
+         objectName = Convert(duRequest);
+   }
+   else
+   {
       MvRequest modeRequest = duRequest.getSubrequest("_MODE");
       if ( (const char *) duRequest("_NAME") )
          modeRequest("_NAME") = duRequest("_NAME");
@@ -275,10 +279,10 @@ ObjectInfo::ConvertDataUnitToMacro ( MvIcon& dataUnit )
       if ( (const char *) duRequest("_APPL") )
          modeRequest("_APPL") = duRequest("_APPL");
 
-      MvIcon tmpIcon(modeRequest);
       // Call itself with the mode request.
+      MvIcon tmpIcon(modeRequest);
       objectName = ConvertDataUnitToMacro(tmpIcon);
-    }
+   }
 
    return objectName;
 }
@@ -366,9 +370,6 @@ ObjectInfo::ObjectPath ( const MvRequest& request )
   Cached path;
 
   const char* mPath = request( "_PATH" );
-//  if ( ! mPath )
-//    mPath = request( "_PATH" );
-
   if ( mPath )
     //              Path contains file name, it shouldn't but .....
     //              If it's been corrected, use following commented line
@@ -389,7 +390,7 @@ ObjectInfo::ObjectPath ( const MvRequest& request )
     {
       // Obtain the fully qualified path to the object
       const char* mvPath = request ( "_NAME" );
-      path               = MakeUserPath ( dirname ( mvPath  ) );
+      path = MakeUserPath( dirname(mvPath) ).c_str();
     }
 
   // Try to open a directory - if failed, set the path to METVIEW_USER_DIR
@@ -515,36 +516,13 @@ ObjectInfo::CalledFromMacro ( const MvRequest& request )
 //
 // -- PURPOSE:  Indicate the icon Class
 //
-// -- INPUT  :  a fully-qualified path 
-//              the name of the icon
+// -- INPUT  :  Request
 //
 // -- OUTPUT :  The class of the icon
 //
-// -- NOTES  :  This method uses the "hidden" user interface
-//              requestes, which are also used by MetvuewUI
-//              to identify the objects
 Cached
 ObjectInfo::IconClass ( const MvRequest &req )
 {
-    Cached path = ObjectPath(req);
-    Cached iconName = ObjectName(req);
-
-    // Create a path to a hidden file (MetviewUI)
-    Cached hiddenFileName = path + Cached("/.") + iconName;
-
-    // If the file exists, read it (MetviewUI)
-    if ( FileCanBeOpened ( hiddenFileName, "r" )  == true )
-    {
-        MvRequest uiRequest;
-        uiRequest.read  ( (const char*) hiddenFileName );
-
-        // Obtain the value of the icon class
-        Cached iconClass;
-        uiRequest.getValue ( iconClass, "ICON_CLASS", 0 );
-
-        return iconClass;
-    }
-
     // Get info from parameter _CLASS (Desktop)
     if ( (const char*)req("_CLASS") )
         return (const char*)req("_CLASS");
@@ -656,46 +634,52 @@ ObjectInfo::CheckVisDefClass (const MvRequest& req1, const MvRequest& req2)
 Cached
 ObjectInfo::Convert(MvRequest &req)
 {
-  int first = 0;
-  Cached returnName, oneReqName;
+   int first = 0;
+   Cached returnName, oneReqName;
 
-  while ( req )
-    {
+   while ( req )
+   {
       Cached iconClass = ObjectInfo::IconClass ( req );
       MacroConverter & converter = MacroConverter::Find(iconClass );
 
-      Cached fileName = ObjectInfo::ObjectPath(req) + Cached("/") + 
-	ObjectInfo::ObjectName(req);
-      oneReqName = "";
-      if ( ! IsBinaryOrMissingFile( fileName ) )
-	{
-	  MvRequest fileReq;
-	  fileReq.read(fileName);
+      string objName  = (const char*)ObjectInfo::ObjectName(req);
+      string fileName = (const char*)ObjectInfo::ObjectPath(req);
+      fileName += (fileName[fileName.size()-1] == '/') ? objName :  "/" + objName;
 
-	  // Just in case further expansion is needed.
-	  fileReq("_NAME") = req("_NAME");
-	  oneReqName = converter.Convert(fileReq, this);
-	}
+      oneReqName = "";
+      if ( ! IsBinaryOrMissingFile( fileName.c_str() ) )
+      {
+         MvRequest fileReq;
+         fileReq.read(fileName.c_str(),true);
+
+         // Just in case further expansion is needed
+         if ( !(const char*)fileReq("_PATH") && (const char*)req("_PATH") )
+            fileReq("_PATH") = req("_PATH");
+         if ( !(const char*)fileReq("_NAME") && (const char*)req("_NAME") )
+            fileReq("_NAME") = req("_NAME");
+
+         oneReqName = converter.Convert(fileReq, this);
+      }
 
       if ( oneReqName == Cached("") )
-	oneReqName = converter.Convert(req, this);
+         oneReqName = converter.Convert(req, this);
 
       if ( first == 1 )
-	returnName = Cached("[") + returnName;
+         returnName = Cached("[") + returnName;
 
       if ( first > 0 )
-	returnName = returnName + Cached(", ");
+         returnName = returnName + Cached(", ");
 
       returnName = returnName + oneReqName;
       first++;
 
       req.advance();
-    }
+   }
 
-  if ( first > 1 )
-	returnName = returnName + Cached("] ");
+   if ( first > 1 )
+      returnName = returnName + Cached("] ");
 
-  return returnName;
+   return returnName;
 }
 
 void ObjectInfo::FormatLine(const Cached &param, const Cached &val, const Cached &comma, int width)
