@@ -798,31 +798,45 @@ ObjectList::CalledFromMacro ( const MvRequest& request )
 // -- PURPOSE:  Return the expected parameter to make a pair in a vector field.
 //              ex. U/V, D/T... and the correspondent wind mode
 //
-// -- INPUT  :  A parameter (the first in the pair)
+// -- INPUT  :  param: parameter name
 //
-// -- OUTPUT :  The second parameter of the pair and the related wind mode plotting
-//              or "no_pair" for scalar data 
-//
-void ObjectList::GetCompanion ( const string& param, string& pair, string& mode )
+// -- OUTPUT :  pair : pair name ("no_pair" for scalar data)
+//              mode : wind mode plotting
+//              first: true - if there is a companion and the input parameter 
+//                            is the primarely/first element, i.e. it is not 
+//                            the friend element
+void ObjectList::GetCompanion ( const string& param, string& pair, string& mode, bool& first )
 {
-	MvRequest& objectList = ObjectList::Instance();
+   MvRequest& objectList = ObjectList::Instance();
+   objectList.rewind();
 
-	objectList.rewind();
-	string comp("companion");
-	while ( objectList )
-	{
-		if ( objectList.getVerb() == comp  && (const char*)objectList("class") == param )
-        {
+   string comp("companion");
+   while ( objectList )
+   {
+      if ( objectList.getVerb() == comp )
+      {
+         if ( (const char*)objectList("class") == param )
+         {
             pair = (const char*)objectList( "friend" );
             mode = (const char*)objectList("mode") ? (const char*)objectList("mode") : "";
+            first = true;
             return;
-        }
-		objectList.advance();
-	}
+         }
+         else if ( (const char*)objectList("friend") == param )
+         {
+            pair = (const char*)objectList( "class" );
+            mode = (const char*)objectList("mode") ? (const char*)objectList("mode") : "";
+            first = false;
+            return;
+         }
+      }
+      objectList.advance();
+   }
 
-    pair = "no_pair";
-    mode = "";
-	return;
+   pair = "no_pair";
+   mode = "";
+   first= false;
+   return;
 }
 
 // Check if two variables are companions
