@@ -56,14 +56,14 @@ ThermoViewFactory::Build ( Page& page,
 ThermoView::ThermoView ( Page& owner,
                          const MvRequest& viewRequest,
                          const MvRequest& setupRequest ):
-                              CommonXSectView ( owner, viewRequest, setupRequest ),
-                              type_     ("TEPHIGRAM")
+               CommonXSectView ( owner, viewRequest, setupRequest ),
+               type_("TEPHIGRAM")
 {
    SetVariables(viewRequest,true);
 }
 
 ThermoView::ThermoView ( const ThermoView &old ) :
-                              CommonXSectView(old)
+               CommonXSectView(old)
 {
    type_ = old.type_;
 }
@@ -80,7 +80,7 @@ void ThermoView::DescribeYourself ( ObjectInfo& description )
 {
    // Convert my request to Macro
    set<Cached> skipSet;
-   description.ConvertRequestToMacro ( viewRequest_, PUT_END, MacroName().c_str(),"thermoview", skipSet);
+   description.ConvertRequestToMacro ( appViewReq_, PUT_END, MacroName().c_str(),"thermoview", skipSet);
    description.PutNewLine (" " );
 }
 
@@ -96,14 +96,16 @@ bool ThermoView::UpdateView ()
    if ( string(viewRequest_.getVerb()) == CARTESIANVIEW )
       return true;
 
-   // Translate common parameters
-   //GetCommonParameters ( req, cartView );
+   // Create a Cartesian View request related to Tephigram
+   // Magics requires that the value for parameter map_projection be 
+   // in lower case
+   MvRequest cartView("CARTESIANVIEW");
+   string sdata = type_;
+   std::transform(sdata.begin(), sdata.end(), sdata.begin(), ::tolower);
+   cartView("MAP_PROJECTION") = sdata.c_str();
 
    // Translate axes min/max values
-   MvRequest cartView("CARTESIANVIEW");
-   cartView("MAP_PROJECTION") = "tephigram";
-
-   // Check where the axes min/max values should be taken from
+   // Check where the values should be taken from
    if ( (const char*)viewRequest_("_DEFAULT") &&
         (int)viewRequest_("_DEFAULT") == 1 &&
         (const char*)viewRequest_("_DATAATTACHED") &&
@@ -117,16 +119,14 @@ bool ThermoView::UpdateView ()
    {
       cartView("X_AUTOMATIC") = "off";
       cartView("Y_AUTOMATIC") = "off";
+
+      // Get min/max axes coordinates
       cartView("X_MIN") = viewRequest_("MINIMUM_TEMPERATURE");
       cartView("X_MAX") = viewRequest_("MAXIMUM_TEMPERATURE");
       cartView("Y_MIN") = viewRequest_("BOTTOM_PRESSURE");
       cartView("Y_MAX") = viewRequest_("TOP_PRESSURE");
    }
 
-//ostringstream oss;
-//oss << "Thermo: Diagram type not implemented yet: " << type_;
-//PlotMod::Instance().MetviewError (oss.str().c_str(),"WARNING");
-
    // Copy ThermoGrid definition
    MvRequest reqGrid = viewRequest_.getSubrequest("THERMO_GRID");
    if ( reqGrid )
@@ -200,42 +200,23 @@ void ThermoView::UpdateView ( MvRequest& viewRequest )
    //Owner().InitZoomStacks();
 }
 
-void ThermoView::ApplicationInfo( const MvRequest& )
+void ThermoView::ApplicationInfo( const MvRequest& req)
 {
- #if 0
-  // If it is not a VIEW request, try to find a hidden VIEW in the request
+   // Get the VIEW request
    MvRequest viewReq;
    if ( ObjectList::IsView(req.getVerb()) )
       viewReq = req;
    else
    {
-      MvRequest aux = req.getSubrequest("NETCDF_DATA");
-      if ( (const char*)aux("_CARTESIANVIEW") )
-         viewReq = aux.getSubrequest("_CARTESIANVIEW");
-      else
+      // Try to find a hidden VIEW in the request
+      viewReq = req.getSubrequest("_VIEW_REQUEST");
+      if ( !viewReq )
       {
-         PlotMod::Instance().MetviewError ("Missing View Request in ThermoView::ApplicationInfo","WARNING");
+         // Nothing to be done
          return;
       }
    }
 
-   // Update the DATE_MIN/MAX parameters in the View if the original values
-   // were AUTOMATIC and the Thermo application provided new values
-   if ( bDateMin_ )
-   {
-      string str = (const char*)viewReq("X_DATE_MIN") ? "X_DATE_MIN" : "Y_DATE_MIN";
-      dateMin_ = (const char*)viewReq(str.c_str());
-      viewRequest_(str.c_str()) = dateMin_.c_str();
-      bDateMin_ = false;
-   }
-   if ( bDateMax_ )
-   {
-      string str = (const char*)viewReq("X_DATE_MAX") ? "X_DATE_MAX" : "Y_DATE_MAX";
-      dateMax_ = (const char*)viewReq(str.c_str());
-      viewRequest_(str.c_str()) = dateMax_.c_str();
-      bDateMax_ = false;
-   }
-#endif
    return;
 }
 
